@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ typedef NSMenu *MENUHANDLE;
 
 using namespace ipe;
 
-constexpr int COPYRIGHT_YEAR = 2021;
+constexpr int COPYRIGHT_YEAR = 2022;
 
 #define IPEABSOLUTE "<absolute>"
 
@@ -121,7 +121,7 @@ public:  // What platforms must implement:
   virtual void setWindowCaption(bool mod, const char *s) = 0;
   virtual void setNotes(String notes) = 0;
   virtual void explain(const char *s, int t) = 0;
-  virtual void showWindow(int width, int height, int x, int y) = 0;
+  virtual void showWindow(int width, int height, int x, int y, const Color & pathViewColor) = 0;
   virtual void setFullScreen(int mode) = 0;
   virtual void action(String name) = 0;
   virtual void setActionsEnabled(bool mode) = 0;
