@@ -3,7 +3,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -1386,7 +1386,7 @@ void AppUi::setWindowCaption(bool mod, const char *s)
   [iWindow setTitle:[[NSString alloc] initWithUTF8String:s]];
 }
 
-void AppUi::showWindow(int width, int height, int x, int y)
+void AppUi::showWindow(int width, int height, int x, int y, const Color & pathViewColor)
 {
   if (width > 0 && height > 0) {
     NSRect e = [[NSScreen mainScreen] frame];
