@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -920,7 +920,7 @@ static const char * const aboutText =
 void AppUi::aboutIpe()
 {
   std::vector<char> buf(strlen(aboutText) + 100);
-  sprintf(&buf[0], aboutText,
+  sprintf(buf.data(), aboutText,
 	  IPELIB_VERSION / 10000,
 	  (IPELIB_VERSION / 100) % 100,
 	  IPELIB_VERSION % 100,
@@ -929,7 +929,7 @@ void AppUi::aboutIpe()
   QMessageBox msgBox(this);
   msgBox.setWindowTitle("About Ipe");
   msgBox.setWindowIcon(prefsIcon("ipe"));
-  msgBox.setInformativeText(&buf[0]);
+  msgBox.setInformativeText(buf.data());
   msgBox.setIconPixmap(prefsPixmap("ipe"));
   msgBox.setStandardButtons(QMessageBox::Ok);
   msgBox.exec();
@@ -1047,8 +1047,9 @@ void AppUi::explain(const char *s, int t)
   statusBar()->showMessage(QString::fromUtf8(s), t);
 }
 
-void AppUi::showWindow(int width, int height, int x, int y)
+void AppUi::showWindow(int width, int height, int x, int y, const Color & pathViewColor)
 {
+  iPathView->setColor(pathViewColor);
   if (width > 0 && height > 0)
     resize(width, height);
   if (x >= 0 && y >= 0)
