@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ public:
   virtual void setActionState(const char *name, bool value) override;
   virtual void setWindowCaption(bool mod, const char *s) override;
   virtual void explain(const char *s, int t) override;
-  virtual void showWindow(int width, int height, int x, int y) override;
+  virtual void showWindow(int width, int height, int x, int y, const Color & pathViewColor) override;
   virtual void setFullScreen(int mode) override;
   virtual void setBookmarks(int no, const String *s) override;
   virtual void setToolVisible(int m, bool vis) override;
