@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -1360,13 +1360,13 @@ static const char * const aboutText =
 void AppUi::aboutIpe()
 {
   std::vector<char> buf(strlen(aboutText) + 100);
-  sprintf(&buf[0], aboutText,
+  sprintf(buf.data(), aboutText,
 	  IPELIB_VERSION / 10000,
 	  (IPELIB_VERSION / 100) % 100,
 	  IPELIB_VERSION % 100,
 	  COPYRIGHT_YEAR);
 
-  WString wbuf(&buf[0]);
+  WString wbuf(buf.data());
   MessageBoxW(hwnd, wbuf.data(), L"About Ipe",
 	      MB_OK | MB_ICONINFORMATION | MB_APPLMODAL);
 }
@@ -1437,8 +1437,9 @@ void AppUi::setWindowCaption(bool mod, const char *s)
   setWindowText(hwnd, s);
 }
 
-void AppUi::showWindow(int width, int height, int x, int y)
+void AppUi::showWindow(int width, int height, int x, int y, const Color &pathViewColor)
 {
+  iPathView->setColor(pathViewColor);
   SetWindowPos(hwnd, nullptr, x, y, width, height, (x < 0) ? SWP_NOMOVE : 0);
   ShowWindow(hwnd, win_nCmdShow);
   UpdateWindow(hwnd);
