@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -81,6 +81,7 @@ class PathView : public QWidget {
 
 public:
   PathView(int uiScale, QWidget* parent = nullptr, Qt::WindowFlags f = nullptr);
+  void setColor(const Color & color);
 
   void set(const AllAttributes &all, Cascade *sheet);
 
@@ -100,6 +101,7 @@ private:
   int iUiScale;
   Cascade *iCascade;
   AllAttributes iAll;
+  Color iColor;
 };
 
 // --------------------------------------------------------------------
