@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@ public:
   PathView(HWND parent, int id);
 
   HWND windowId() const { return hwnd; }
+  void setColor(const Color & color);
   void set(const AllAttributes &all, Cascade *sheet);
 
   inline POINT popupPos() const { return pos; }
@@ -64,6 +65,7 @@ private:
   Cascade *iCascade;
   AllAttributes iAll;
   String iAction;
+  Color iColor;
 };
 
 // --------------------------------------------------------------------
