@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -61,29 +61,6 @@ function cloneSubpath(sp)
   return nsp
 end
 
-local function recomputeMatrix(seg, cpno)
-  local alpha, beta = seg.arc:angles()
-  local p = ipe.Direction(alpha)
-  local q = ipe.Direction(beta)
-  local cl
-  if cpno == 1 then
-    cl = ipe.LineThrough(V(0,0), q)
-    p = seg.arc:matrix():inverse() * seg[cpno]
-  else -- cpno == 2
-    cl = ipe.LineThrough(V(0,0), p)
-    q = seg.arc:matrix():inverse() * seg[cpno]
-  end
-  local center = ipe.Bisector(p, q):intersects(cl)
-  if center and center:sqLen() < 1e10 then
-    local radius = (p - center):len()
-    alpha = (p - center):angle()
-    beta = (q - center):angle()
-    local m = (seg.arc:matrix() *
-	     ipe.Matrix(radius, 0, 0, radius, center.x, center.y))
-    seg.arc = ipe.Arc(m, alpha, beta)
-  end
-end
-
 function moveCP(shape, spno, segno, cpno, v)
   local sp = shape[spno]
   if sp.type == "closedspline" then
@@ -127,12 +104,12 @@ function moveCP(shape, spno, segno, cpno, v)
       elseif cpno == #seg and segno < #sp then
 	sp[segno + 1][1] = v
       end
-      if seg.type == "arc" then recomputeMatrix(seg, cpno) end
+      if seg.type == "arc" then recomputeArcMatrix(seg, cpno) end
       if segno > 1 and cpno == 1 and sp[segno - 1].type == "arc" then
-	recomputeMatrix(sp[segno - 1], 2)
+	recomputeArcMatrix(sp[segno - 1], 2)
       end
       if segno < #sp and cpno == #seg and sp[segno + 1].type == "arc" then
-	recomputeMatrix(sp[segno + 1], 1)
+	recomputeArcMatrix(sp[segno + 1], 1)
       end
     end
   end
