@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -150,6 +150,30 @@ function transformShape(matrix, shape)
   end
 end
 
+-- recompute matrix of an arc after an endpoint has been moved
+function recomputeArcMatrix(seg, cpno)
+  local alpha, beta = seg.arc:angles()
+  local p = ipe.Direction(alpha)
+  local q = ipe.Direction(beta)
+  local cl
+  if cpno == 1 then
+    cl = ipe.LineThrough(V(0,0), q)
+    p = seg.arc:matrix():inverse() * seg[cpno]
+  else -- cpno == 2
+    cl = ipe.LineThrough(V(0,0), p)
+    q = seg.arc:matrix():inverse() * seg[cpno]
+  end
+  local center = ipe.Bisector(p, q):intersects(cl)
+  if center and center:sqLen() < 1e10 then
+    local radius = (p - center):len()
+    alpha = (p - center):angle()
+    beta = (q - center):angle()
+    local m = (seg.arc:matrix() *
+	     ipe.Matrix(radius, 0, 0, radius, center.x, center.y))
+    seg.arc = ipe.Arc(m, alpha, beta)
+  end
+end
+
 function findStyle(w, dir)
   if dir and ipe.fileExists(dir .. prefs.fsep .. w) then
     return dir .. prefs.fsep .. w
