@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -554,8 +554,12 @@ function MODEL:newDocument()
 
   self.doc = ipe.Document()
   for _, w in ipairs(config.styleList) do
-    local sheet = assert(ipe.Sheet(w))
-    self.doc:sheets():insert(1, sheet)
+    local sheet = ipe.Sheet(w)
+    if not sheet then
+      self:warning("Style sheet '" .. w .. "' could not be read.")
+    else
+      self.doc:sheets():insert(1, sheet)
+    end
   end
   local p = self.doc:properties()
   p.tex = prefs.tex_engine
@@ -724,15 +728,21 @@ function MODEL:autosave()
   -- only autosave if document has been modified
   if not self:isModified() then return end
   local f
-  if prefs.autosave_filename:find("%%s") then
-    if self.file_name then
+  if self.file_name then
+    if prefs.autosave_filename:find("%%s") then
       f = self.file_name:match(prefs.basename_pattern) or self.file_name
+      f = string.format(prefs.autosave_filename, f)
     else
-      f = "unnamed"
+      f = prefs.autosave_filename
+    end
+    if f[1] ~= prefs.fsep then -- relative filename
+      local d = self.file_name:match(prefs.dir_pattern)
+      if d then
+        f = d .. prefs.fsep .. f
+      end
     end
-    f = string.format(prefs.autosave_filename, f)
   else
-    f = prefs.autosave_filename
+    f = prefs.autosave_unnamed
   end
   self.ui:explain("Autosaving to " .. f .. "...")
   if not self.doc:save(f, "xml") then
