@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -60,6 +60,12 @@ PathView::PathView(HWND parent, int id)
   assert(GetWindowLongPtr(hwnd, GWLP_USERDATA));
 }
 
+void PathView::setColor(const Color & color)
+{
+  iColor = color;
+  InvalidateRect(hwnd, nullptr, FALSE);
+}
+
 void PathView::set(const AllAttributes &all, Cascade *sheet)
 {
   iCascade = sheet;
@@ -120,7 +126,9 @@ void PathView::wndPaint()
   cairo_surface_t *surface = cairo_win32_surface_create(hdc);
   cairo_t *cc = cairo_create(surface);
 
-  cairo_set_source_rgb(cc, 1, 1, 0.8);
+  cairo_set_source_rgb(cc, iColor.iRed.toDouble(),
+		       iColor.iGreen.toDouble(),
+		       iColor.iBlue.toDouble());
   cairo_rectangle(cc, 0, 0, w, h);
   cairo_fill(cc);
 
