@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -572,7 +572,7 @@ static int appui_setBookmarks(lua_State *L)
     bm.push_back(String(lua_tolstring(L, -1, nullptr)));
     lua_pop(L, 1);
   }
-  (*ui)->setBookmarks(no, &bm[0]);
+  (*ui)->setBookmarks(no, bm.data());
   return 0;
 }
 
@@ -810,6 +810,11 @@ static int appui_constructor(lua_State *L)
   style.paperColor = Color(1000,1000,1000);
   style.primarySelectionColor = Color(1000,0,0);
   style.secondarySelectionColor = Color(1000,0,1000);
+  style.selectionSurroundColor = Color(1000, 1000, 0);
+  style.primarySelectionWidth = 3.0;
+  style.secondarySelectionWidth = 2.0;
+  style.selectionSurroundWidth = 6.0;
+  style.gridLineColor = Color(300, 300, 300);
   style.classicGrid = false;
   style.thinLine = 0.2;
   style.thickLine = 0.9;
@@ -818,6 +823,8 @@ static int appui_constructor(lua_State *L)
   style.paperClip = false;
   style.numberPages = false;
 
+  Color pathViewColor = Color(1000, 1000, 800);
+
   lua_getglobal(L, "prefs");
 
   lua_getfield(L, -1, "canvas_style");
@@ -837,6 +844,36 @@ static int appui_constructor(lua_State *L)
       style.secondarySelectionColor = check_color(L, lua_gettop(L));
     lua_pop(L, 1); // secondary_color
 
+    lua_getfield(L, -1, "surround_color");
+    if (!lua_isnil(L, -1))
+      style.selectionSurroundColor = check_color(L, lua_gettop(L));
+    lua_pop(L, 1); // surround_color
+
+    lua_getfield(L, -1, "primary_width");
+    if (lua_isnumber(L, -1))
+      style.primarySelectionWidth = lua_tonumberx(L, -1, nullptr);
+    lua_pop(L, 1); // primary_width
+
+    lua_getfield(L, -1, "secondary_width");
+    if (lua_isnumber(L, -1))
+      style.secondarySelectionWidth = lua_tonumberx(L, -1, nullptr);
+    lua_pop(L, 1); // secondary_width
+
+    lua_getfield(L, -1, "surround_width");
+    if (lua_isnumber(L, -1))
+      style.selectionSurroundWidth = lua_tonumberx(L, -1, nullptr);
+    lua_pop(L, 1); // surround_width
+
+    lua_getfield(L, -1, "grid_line_color");
+    if (!lua_isnil(L, -1))
+      style.gridLineColor = check_color(L, lua_gettop(L));
+    lua_pop(L, 1); // grid_line_color
+
+    lua_getfield(L, -1, "path_view_color");
+    if (!lua_isnil(L, -1))
+      pathViewColor = check_color(L, lua_gettop(L));
+    lua_pop(L, 1); // path_view_color
+
     lua_getfield(L, -1, "classic_grid");
     style.classicGrid = lua_toboolean(L, -1);
     lua_pop(L, 1); // classic_grid
@@ -886,7 +923,7 @@ static int appui_constructor(lua_State *L)
 
   (*ui)->canvas()->setCanvasStyle(style);
 
-  (*ui)->showWindow(width, height, x, y);
+  (*ui)->showWindow(width, height, x, y, pathViewColor);
 
   return 1;
 }
