@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -93,6 +93,11 @@ CanvasBase::CanvasBase()
   iStyle.paperColor = Color(1000,1000,1000);
   iStyle.primarySelectionColor = Color(1000, 0, 0);
   iStyle.secondarySelectionColor= Color(1000, 0, 1000);
+  iStyle.selectionSurroundColor = Color(1000, 1000, 0);
+  iStyle.gridLineColor = Color(300, 300, 300);
+  iStyle.primarySelectionWidth = 3.0;
+  iStyle.secondarySelectionWidth = 2.0;
+  iStyle.selectionSurroundWidth = 6.0;
   iStyle.pretty = false;
   iStyle.classicGrid = false;
   iStyle.thinLine = 0.2;
@@ -280,7 +285,9 @@ void CanvasBase::drawGrid(cairo_t *cc)
   Vector screenLR = devToUser(Vector(iWidth, iHeight));
 
   cairo_save(cc);
-  cairo_set_source_rgb(cc, 0.3, 0.3, 0.3);
+  cairo_set_source_rgb(cc, iStyle.gridLineColor.iRed.toDouble(),
+		       iStyle.gridLineColor.iGreen.toDouble(),
+		       iStyle.gridLineColor.iBlue.toDouble());
 
   if (iStyle.classicGrid) {
     double lw = iStyle.thinLine / iZoom;
@@ -499,12 +506,18 @@ void CanvasBase::drawTool(Painter &painter)
     for (int i = 0; i < iPage->count(); ++i) {
       if (iPage->objectVisible(iView, i)) {
 	if (iPage->select(i) == EPrimarySelected) {
+	  painter.setStroke(Attribute(iStyle.selectionSurroundColor));
+	  painter.setPen(Attribute(Fixed(iStyle.selectionSurroundWidth)));
+	  iPage->object(i)->drawSimple(painter);
 	  painter.setStroke(Attribute(iStyle.primarySelectionColor));
-	  painter.setPen(Attribute(Fixed(2)));
+	  painter.setPen(Attribute(Fixed(iStyle.primarySelectionWidth)));
 	  iPage->object(i)->drawSimple(painter);
 	} else if (iPage->select(i) == ESecondarySelected) {
+	  painter.setStroke(Attribute(iStyle.selectionSurroundColor));
+	  painter.setPen(Attribute(Fixed(iStyle.selectionSurroundWidth)));
+	  iPage->object(i)->drawSimple(painter);
 	  painter.setStroke(Attribute(iStyle.secondarySelectionColor));
-	  painter.setPen(Attribute(Fixed(1)));
+	  painter.setPen(Attribute(Fixed(iStyle.secondarySelectionWidth)));
 	  iPage->object(i)->drawSimple(painter);
 	}
       }
