@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -239,13 +239,20 @@ void Canvas::mouseMoveEvent(QMouseEvent *ev)
 
 void Canvas::tabletEvent(QTabletEvent *ev)
 {
+  static bool pressed = false;
   Vector globalPos(ev->hiResGlobalX(), ev->hiResGlobalY());
   QPointF hiPos = ev->posF();
-  ev->accept();
 
   switch (ev->type()) {
   case QEvent::TabletPress:
-    ipeDebug("TabletPress: %d %d", ev->button(), ev->pointerType());
+    if (pressed) {
+      ev->ignore();
+      pressed = false;
+      return;
+    }
+    ipeDebug("TabletPress: %d %d %ld", ev->button(), ev->pointerType(), ev->timestamp());
+    pressed = true;
+    ev->accept();
     iGlobalPos = globalPos;
     computeFifi(hiPos.x(), hiPos.y());
     if (ev->pointerType() == QTabletEvent::Eraser) {
@@ -260,6 +267,7 @@ void Canvas::tabletEvent(QTabletEvent *ev)
     break;
   case QEvent::TabletMove:
     if (ev->pressure() > 0.01) {
+      ev->accept();
       computeFifi(hiPos.x(), hiPos.y());
       if (iTool)
 	iTool->mouseMove();
@@ -269,6 +277,8 @@ void Canvas::tabletEvent(QTabletEvent *ev)
     }
     // else fall through and consider it a release event
   case QEvent::TabletRelease:
+    pressed = false;
+    ev->accept();
     iGlobalPos = globalPos;
     computeFifi(hiPos.x(), hiPos.y());
     if (iTool)
@@ -284,8 +294,13 @@ void Canvas::wheelEvent(QWheelEvent *ev)
 {
   QPoint p = ev->angleDelta();
   int kind = (ev->modifiers() & Qt::ControlModifier) ? 2 : 0;
-  if (iObserver)
-    iObserver->canvasObserverWheelMoved(p.x() / 8.0, p.y() / 8.0, kind);
+  if (iObserver) {
+    if (ev->modifiers() & Qt::ShiftModifier)
+      // switch x and y
+      iObserver->canvasObserverWheelMoved(p.y() / 8.0, p.x() / 8.0, kind);
+    else
+      iObserver->canvasObserverWheelMoved(p.x() / 8.0, p.y() / 8.0, kind);
+  }
   ev->accept();
 }
 
