@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -171,7 +171,7 @@ int showPageSelectDialog(int width, int height, const char * title,
   t.push_back(0);
   t.push_back(0);
 
-  int res = DialogBoxIndirectParamW(nullptr, (LPCDLGTEMPLATE) &t[0],
+  int res = DialogBoxIndirectParamW(nullptr, (LPCDLGTEMPLATE) t.data(),
 				    nullptr, dialogProc, (LPARAM) &sData);
   return res;
 }
