@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -163,6 +163,17 @@ void Effect::pageDictionary(Stream &stream) const
     case EGlitterLR: stream << "/Glitter /Di 0"; break;
     case EGlitterTB: stream << "/Glitter /Di 270"; break;
     case EGlitterD: stream << "/Glitter /Di 315"; break;
+    case EFlyILR: stream << "/Fly /M /I /Di 0"; break;
+    case EFlyOLR: stream << "/Fly /M /O /Di 0"; break;
+    case EFlyITB: stream << "/Fly /M /I /Di 270"; break;
+    case EFlyOTB: stream << "/Fly /M /O /Di 270"; break;
+    case EPushLR: stream << "/Push /Di 0"; break;
+    case EPushTB: stream << "/Push /Di 270"; break;
+    case ECoverLR: stream << "/Cover /Di 0"; break;
+    case ECoverLB: stream << "/Cover /Di 270"; break;
+    case EUncoverLR: stream << "/Uncover /Di 0"; break;
+    case EUncoverTB: stream << "/Uncover /Di 270"; break;
+    case EFade: stream << "/Fade"; break;
     case ENormal: break; // to satisfy compiler
     }
     stream << " >>\n";
