@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2020 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -234,10 +234,13 @@ int Latex::createLatexSource(Stream &stream, String preamble)
 	 << "\\begin{document}\n"
 	 << "\\begin{picture}(500,500)\n";
 
-  int curnum = 1;
   if (iXetex)
     stream << "\\special{pdf:obj @ipeforms []}\n";
+
+  // generate Latex source for each text object
   for (auto &it : iTextObjects) {
+    StringStream source(it.iSource);
+
     const Text *text = it.iText;
 
     if (!text->getXForm())
@@ -246,24 +249,22 @@ int Latex::createLatexSource(Stream &stream, String preamble)
     Attribute fsAttr = iCascade->find(ETextSize, it.iSize);
 
     // compute x-stretch factor from textstretch
-    Fixed stretch(1);
+    it.iStretch = Fixed(1);
     if (it.iSize.isSymbolic())
-      stretch = iCascade->find(ETextStretch, it.iSize).number();
-
-    stream << "\\setbox0=\\hbox{";
+      it.iStretch = iCascade->find(ETextStretch, it.iSize).number();
     if (text->isMinipage()) {
-      stream << "\\begin{minipage}{" <<
-	text->width()/stretch.toDouble() << "bp}";
+      source << "\\begin{minipage}{" <<
+	text->width()/it.iStretch.toDouble() << "bp}";
     }
 
     if (fsAttr.isNumber()) {
       Fixed fs = fsAttr.number();
-      stream << "\\fontsize{" << fs << "}"
+      source << "\\fontsize{" << fs << "}"
 	     << "{" << fs.mult(6, 5) << "bp}\\selectfont\n";
     } else
-      stream << fsAttr.string() << "\n";
+      source << fsAttr.string() << "\n";
     Color col = iCascade->find(EColor, text->stroke()).color();
-    stream << "\\ipesetcolor{" << col.iRed.toDouble()
+    source << "\\ipesetcolor{" << col.iRed.toDouble()
 	   << "}{" << col.iGreen.toDouble()
 	   << "}{" << col.iBlue.toDouble()
 	   << "}%\n";
@@ -275,21 +276,34 @@ int Latex::createLatexSource(Stream &stream, String preamble)
     int sp = 0;
     while (sp < style.size() && style[sp] != '\0')
       ++sp;
-    stream << style.substr(0, sp);
+    source << style.substr(0, sp);
 
     String txt = text->text();
-    stream << txt;
+    source << txt;
 
     if (text->isMinipage()) {
       if (!txt.empty() && txt[txt.size() - 1] != '\n')
-	stream << "\n";
-      stream << style.substr(sp + 1);
-      stream << "\\end{minipage}";
+	source << "\n";
+      source << style.substr(sp + 1);
+      source << "\\end{minipage}";
     } else
-      stream << style.substr(sp + 1) << "%\n";
+      source << style.substr(sp + 1) << "%\n";
+  }
 
+  std::sort(iTextObjects.begin(), iTextObjects.end(),
+	    [](const SText &a, const SText &b) {
+	      return a.iSource < b.iSource;
+	    });
+
+  for (int i = 0; i < size(iTextObjects); ++i) {
+    auto & it = iTextObjects[i];
+    if (i > 0 && it.iSource == iTextObjects[i-1].iSource)
+      continue;
+    stream << "\\setbox0=\\hbox{";
+    stream << it.iSource;
     stream << "\\iperesetcolor}\n"
 	   << "\\count0=\\dp0\\divide\\count0 by \\bigpoint\n";
+    int curnum = i + 1;
     if (iXetex) {
       stream << "\\special{ pdf:bxobj @ipeform" << curnum << "\n"
 	     << "width \\the\\wd0 \\space "
@@ -299,7 +313,7 @@ int Latex::createLatexSource(Stream &stream, String preamble)
 	     << "\\special{pdf:exobj}%\n"
 	     << "\\special{pdf:obj @ipeinfo" << curnum << " <<"
 	     << " /IpeId " << curnum
-	     << " /IpeStretch " << stretch.toDouble()
+	     << " /IpeStretch " << it.iStretch.toDouble()
 	     << " /IpeDepth \\the\\count0"
 	     << " /IpeXForm @ipeform" << curnum << " >>}\n"
 	     << "\\special{pdf:close @ipeinfo" << curnum << "}\n"
@@ -307,11 +321,10 @@ int Latex::createLatexSource(Stream &stream, String preamble)
 	     << "\\put(0,0){\\special{pdf:uxobj @ipeform" << curnum << "}}\n";
     } else {
       stream << "\\pdfxform attr{/IpeId " << curnum
-	     << " /IpeStretch " << stretch.toDouble()
+	     << " /IpeStretch " << it.iStretch.toDouble()
 	     << " /IpeDepth \\the\\count0}"
 	     << "0\\put(0,0){\\pdfrefxform\\pdflastxform}\n";
     }
-    ++curnum;
   }
   stream << "\\end{picture}\n";
   if (iXetex)
@@ -452,17 +465,27 @@ bool Latex::readPdf(DataSource &source)
 /*! Returns true if successful. */
 bool Latex::updateTextObjects()
 {
-  int curnum = 1;
-  for (auto &it : iTextObjects) {
-    auto xf = std::find_if(iXForms.begin(), iXForms.end(),
-			   [curnum](Text::XForm *f)
-			   { return f->iRefCount == curnum; } );
-    if (xf == iXForms.end())
-      return false;
-    Text::XForm *xform = *xf;
-    iXForms.erase(xf);
-    it.iText->setXForm(xform);
-    ++curnum;
+  std::sort(iXForms.begin(), iXForms.end(),
+	    [](const Text::XForm *a, const Text::XForm *b) {
+	      return a->iRefCount < b->iRefCount;
+	    });
+
+  int curXForm = 0;
+  Text::XForm *xf = nullptr;
+  for (int i = 0; i < size(iTextObjects); ++i) {
+    if (i > 0 && iTextObjects[i].iSource == iTextObjects[i-1].iSource) {
+      if (xf == nullptr)
+	return false;
+      iTextObjects[i].iText->setXForm(xf);
+    } else {
+      if (i + 1 != iXForms[curXForm]->iRefCount)
+	return false;
+      xf = iXForms[curXForm];
+      iXForms[curXForm] = nullptr;
+      xf->iRefCount = 0;
+      iTextObjects[i].iText->setXForm(xf);
+      ++curXForm;
+    }
   }
   return true;
 }
