@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -181,6 +181,9 @@ Object::Object(const XmlAttributes &attr)
     else if (str == "translations")
       iTransformations = ETransformationsTranslations;
   }
+  iCustom = Attribute::UNDEFINED();
+  if (attr.has("custom", str) && !str.empty())
+    iCustom = Attribute(false, str);
 }
 
 /*! Create object by taking pinning/transforming from \a attr and
@@ -189,6 +192,7 @@ Object::Object(const AllAttributes &attr)
 {
   iPinned = attr.iPinned;
   iTransformations = attr.iTransformations;
+  iCustom = Attribute::UNDEFINED();
 }
 
 /*! Create object with identity matrix, no pinning, all transformations. */
@@ -196,6 +200,7 @@ Object::Object()
 {
   iPinned = ENoPin;
   iTransformations = ETransformationsAffine;
+  iCustom = Attribute::UNDEFINED();
 }
 
 //! Copy constructor.
@@ -204,6 +209,7 @@ Object::Object(const Object &rhs)
   iMatrix = rhs.iMatrix;
   iPinned = rhs.iPinned;
   iTransformations = rhs.iTransformations;
+  iCustom = rhs.iCustom;
 }
 
 //! Pure virtual destructor.
@@ -237,6 +243,8 @@ void Object::saveAttributesAsXml(Stream &stream, String layer) const
     stream << " transformations=\"translations\"";
   else if (iTransformations == ETransformationsRigidMotions)
     stream << " transformations=\"rigid\"";
+  if (iCustom != Attribute::UNDEFINED())
+    stream << " custom=\"" << iCustom.string() << "\"";
 }
 
 //! Return pointer to this object if it is an Group, nullptr otherwise.
@@ -343,6 +351,19 @@ Attribute Object::getAttribute(Property prop) const noexcept
   }
 }
 
+//! Set the 'custom' attribute (not used by Ipe, for users and ipelets)
+void Object::setCustom(Attribute value)
+{
+  assert(value.isString());
+  iCustom = value;
+}
+
+//! Return value of the 'custom' attribute
+Attribute Object::getCustom() const noexcept
+{
+  return iCustom;
+}
+
 // --------------------------------------------------------------------
 
 //! Check all symbolic attributes.
