@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -509,6 +509,8 @@ int Platform::runLatex(String dir, LatexType engine, String docname) noexcept
   }
 
   String bat;
+  // try to change codepage to UTF-8
+  bat += "chcp 65001\r\n";
   if (dir.size() > 2 && dir[1] == ':') {
     bat += dir.substr(0, 2);
     bat += "\r\n";
@@ -542,17 +544,11 @@ int Platform::runLatex(String dir, LatexType engine, String docname) noexcept
     bat += "endlocal\r\n";
   // bat += "pause\r\n";  // alternative for Wine
 
-  // CMD.EXE input needs to be encoded in "OEM codepage",
-  // which can be different from "Windows codepage"
-  std::wstring wbat = bat.w();
-  Buffer oemBat(2 * wbat.size() + 1);
-  CharToOemW(wbat.data(), oemBat.data());
-
   String s = dir + "runlatex.bat";
   std::FILE *f = Platform::fopen(s.z(), "wb");
   if (!f)
     return -1;
-  std::fputs(oemBat.data(), f);
+  std::fwrite(bat.data(), 1, bat.size(), f);
   std::fclose(f);
 
   // Declare and initialize process blocks
@@ -642,7 +638,7 @@ std::wstring String::w() const noexcept
     return L"\0";
   int rw = MultiByteToWideChar(CP_UTF8, 0, data(), size(), nullptr, 0);
   std::wstring result(rw + 1, wchar_t(0));
-  MultiByteToWideChar(CP_UTF8, 0, data(), size(), &result[0], rw);
+  MultiByteToWideChar(CP_UTF8, 0, data(), size(), result.data(), rw);
   return result;
 }
 
