@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -597,7 +597,7 @@ void Text::setXForm(XForm *xform) const
     delete iXForm;
   iXForm = xform;
   if (iXForm) {
-    iXForm->iRefCount = 1;
+    ++iXForm->iRefCount;
     iDepth = iXForm->iStretch * iXForm->iDepth / 100.0;
     iHeight = iXForm->iStretch * iXForm->iBBox.height() - iDepth;
     if (!isMinipage())
