@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -543,7 +543,7 @@ static int ipe_splinetobeziers(lua_State *L)
   bool closed = lua_toboolean(L, 2);
   std::vector<Bezier> result;
   if (closed) {
-    Bezier::closedSpline(v.size(), &v[0], result);
+    Bezier::closedSpline(v.size(), v.data(), result);
   } else {
     // get spline type
     lua_getfield(L, 1, "type");
@@ -555,21 +555,21 @@ static int ipe_splinetobeziers(lua_State *L)
     lua_pop(L, 1); // pop type
     switch (type) {
     case CurveSegment::ESpline:
-      Bezier::spline(v.size(), &v[0], result);
+      Bezier::spline(v.size(), v.data(), result);
       break;
     case CurveSegment::EOldSpline:
-      Bezier::oldSpline(v.size(), &v[0], result);
+      Bezier::oldSpline(v.size(), v.data(), result);
       break;
     case CurveSegment::ECardinalSpline: {
       lua_getfield(L, 1, "tension");
       if (!lua_isnumber(L, -1))
 	luaL_error(L, "spline has no tension");
       float tension = lua_tonumberx(L, -1, nullptr);
-      Bezier::cardinalSpline(v.size(), &v[0], tension, result);
+      Bezier::cardinalSpline(v.size(), v.data(), tension, result);
       lua_pop(L, 1); // tension
       break; }
     case CurveSegment::ESpiroSpline:
-      Bezier::spiroSpline(v.size(), &v[0], result);
+      Bezier::spiroSpline(v.size(), v.data(), result);
       break;
     default:
       break;
