@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -405,7 +405,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 static const char * const aboutText =
   "<qt><h1>IpePresenter %d.%d.%d</h1>"
-  "<p>Copyright (c) 2020-2021 Otfried Cheong</p>"
+  "<p>Copyright (c) 2020-2022 Otfried Cheong</p>"
   "<p>A presentation tool for giving PDF presentations "
   "created in Ipe or using beamer.</p>"
   "<p>Originally invented by Dmitriy Morozov, "
@@ -432,14 +432,14 @@ static const char * const aboutText =
 void MainWindow::aboutIpePresenter()
 {
   std::vector<char> buf(strlen(aboutText) + 100);
-  sprintf(&buf[0], aboutText,
+  sprintf(buf.data(), aboutText,
 	  IPELIB_VERSION / 10000,
 	  (IPELIB_VERSION / 100) % 100,
 	  IPELIB_VERSION % 100);
 
   QMessageBox msgBox(this);
   msgBox.setWindowTitle("About IpePresenter");
-  msgBox.setInformativeText(&buf[0]);
+  msgBox.setInformativeText(buf.data());
   msgBox.setStandardButtons(QMessageBox::Ok);
   msgBox.exec();
 }
