@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2022 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -53,6 +53,13 @@
 #include <QThread>
 #include <QTimer>
 
+#ifndef IPE_NO_SPELLCHECK
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#include <QtSpell.hpp>
+#pragma GCC diagnostic pop
+#endif
+
 // --------------------------------------------------------------------
 
 inline void push_string(lua_State *L, const QString &str)
@@ -72,6 +79,20 @@ inline QString checkqstring(lua_State *L, int i)
 
 // --------------------------------------------------------------------
 
+#ifndef IPE_NO_SPELLCHECK
+class TextEdit : public QTextEdit {
+public:
+  TextEdit(QWidget *parent) : QTextEdit(parent) {
+    checker.setTextEdit(this);
+  }
+
+private:
+  QtSpell::TextEditChecker checker;
+};
+#endif
+
+// --------------------------------------------------------------------
+
 class XmlHighlighter : public QSyntaxHighlighter
 {
 public:
@@ -95,10 +116,11 @@ void XmlHighlighter::applyFormat(const QString &text, QRegExp &exp,
 
 void XmlHighlighter::highlightBlock(const QString &text)
 {
+  bool dark = QGuiApplication::palette().text().color().value() > 128;
   QTextCharFormat tagFormat, stringFormat, numberFormat;
   tagFormat.setFontWeight(QFont::Bold);
-  tagFormat.setForeground(Qt::blue);
-  stringFormat.setForeground(Qt::darkMagenta);
+  tagFormat.setForeground(dark ? Qt::yellow : Qt::blue);
+  stringFormat.setForeground(dark ? Qt::cyan : Qt::darkMagenta);
   numberFormat.setForeground(Qt::red);
 
   QRegExp tagExp( "<.*>" );
@@ -140,10 +162,11 @@ void LatexHighlighter::applyFormat(const QString &text, QRegExp &exp,
 
 void LatexHighlighter::highlightBlock(const QString &text)
 {
+  bool dark = QGuiApplication::palette().text().color().value() > 128;
   QTextCharFormat mathFormat, tagFormat;
-  mathFormat.setForeground(Qt::red);
+  mathFormat.setForeground(dark ? Qt::cyan : Qt::red);
   tagFormat.setFontWeight(QFont::Bold);
-  tagFormat.setForeground(Qt::blue);
+  tagFormat.setForeground(dark ? Qt::yellow : Qt::blue);
 
   QRegExp mathExp( "\\$[^$]+\\$" );
   QRegExp tagExp( "\\\\[a-zA-Z]+" );
@@ -321,7 +344,12 @@ bool PDialog::buildAndRun(int w, int h)
 	break;
       case ETextEdit:
 	{
+#ifdef IPE_NO_SPELLCHECK
 	  QTextEdit *t = new QTextEdit(this);
+#else
+	  QTextEdit *t = (m.flags & ELogFile) ?
+	    new QTextEdit(this) : new TextEdit(this);
+#endif
 	  t->setAcceptRichText(false);
 	  if (m.flags & EReadOnly)
 	    t->setReadOnly(true);
